==> isomorphic-path-1.0.0.tgz: package/lib/path.ts <==
import { win32 as win32Base, posix as posixBase } from 'path/path';
import { isWin, isBrowser } from './platform';
import { noop } from './noop';

const unsupportedMethods = {
  resolve: noop,
  relative: noop,
};

const win32Runtime =  Object.assign({}, win32Base, isBrowser() ? unsupportedMethods : {});
const posixRuntime = Object.assign({}, posixBase,  isBrowser() ? unsupportedMethods : {});

let defaultExport;
if (isWin()) {
  defaultExport = Object.assign({}, win32Runtime);
} else {
  defaultExport = Object.assign({}, posixRuntime);
}
let normalizeRuntime;
let joinRuntime;
let resolveRuntime;
let isAbsoluteRuntime;
let relativeRuntime;
let dirnameRuntime;
let basenameRuntime;
let extnameRuntime;
let sepRuntime;
let delimiterRuntime;
let parseRuntime;
let formatRuntime;

if (isWin()) {
  normalizeRuntime = win32Runtime.normalize;
  joinRuntime = win32Runtime.join;
  resolveRuntime = win32Runtime.resolve;
  isAbsoluteRuntime = win32Runtime.isAbsolute;
  relativeRuntime = win32Runtime.relative;
  dirnameRuntime = win32Runtime.dirname;
  basenameRuntime = win32Runtime.basename;
  extnameRuntime = win32Runtime.extname;
  sepRuntime = win32Runtime.sep;
  delimiterRuntime = win32Runtime.delimiter;
  parseRuntime = win32Runtime.parse;
  formatRuntime = win32Runtime.format;
} else {
  normalizeRuntime = posixRuntime.normalize;
  joinRuntime = posixRuntime.join;
  resolveRuntime = posixRuntime.resolve;
  isAbsoluteRuntime = posixRuntime.isAbsolute;
  relativeRuntime = posixRuntime.relative;
  dirnameRuntime = posixRuntime.dirname;
  basenameRuntime = posixRuntime.basename;
  extnameRuntime = posixRuntime.extname;
  sepRuntime = posixRuntime.sep;
  delimiterRuntime = posixRuntime.delimiter;
  parseRuntime = posixRuntime.parse;
  formatRuntime = posixRuntime.format;
}

export default defaultExport;
export {
  normalizeRuntime as normalize,
  joinRuntime as join,
  resolveRuntime as resolve,
  isAbsoluteRuntime as isAbsolute,
  relativeRuntime as relative,
  dirnameRuntime as dirname,
  basenameRuntime as basename,
  extnameRuntime as extname,
  sepRuntime as sepRuntime,
  delimiterRuntime as delimiter,
  parseRuntime as parse,
  formatRuntime as format,
  posixRuntime as posix,
  win32Runtime as win32,
};

==> isomorphic-path-2.0.0.tgz: package/lib/path.ts <==
import { win32 as win32Base, posix as posixBase } from 'path/path';
import { isWin } from './platform';
import { noop } from './noop';

const unsupportedMethods = {
  resolve: noop,
  relative: noop,
};

const win32Runtime = win32Base;
const posixRuntime = posixBase;

let defaultExport;
if (isWin()) {
  defaultExport = Object.assign({}, win32Runtime);
} else {
  defaultExport = Object.assign({}, posixRuntime);
}
let normalizeRuntime;
let joinRuntime;
let resolveRuntime;
let isAbsoluteRuntime;
let relativeRuntime;
let dirnameRuntime;
let basenameRuntime;
let extnameRuntime;
let sepRuntime;
let delimiterRuntime;
let parseRuntime;
let formatRuntime;

if (isWin()) {
  normalizeRuntime = win32Runtime.normalize;
  joinRuntime = win32Runtime.join;
  resolveRuntime = win32Runtime.resolve;
  isAbsoluteRuntime = win32Runtime.isAbsolute;
  relativeRuntime = win32Runtime.relative;
  dirnameRuntime = win32Runtime.dirname;
  basenameRuntime = win32Runtime.basename;
  extnameRuntime = win32Runtime.extname;
  sepRuntime = win32Runtime.sep;
  delimiterRuntime = win32Runtime.delimiter;
  parseRuntime = win32Runtime.parse;
  formatRuntime = win32Runtime.format;
} else {
  normalizeRuntime = posixRuntime.normalize;
  joinRuntime = posixRuntime.join;
  resolveRuntime = posixRuntime.resolve;
  isAbsoluteRuntime = posixRuntime.isAbsolute;
  relativeRuntime = posixRuntime.relative;
  dirnameRuntime = posixRuntime.dirname;
  basenameRuntime = posixRuntime.basename;
  extnameRuntime = posixRuntime.extname;
  sepRuntime = posixRuntime.sep;
  delimiterRuntime = posixRuntime.delimiter;
  parseRuntime = posixRuntime.parse;
  formatRuntime = posixRuntime.format;
}

export default defaultExport;
export {
  normalizeRuntime as normalize,
  joinRuntime as join,
  resolveRuntime as resolve,
  isAbsoluteRuntime as isAbsolute,
  relativeRuntime as relative,
  dirnameRuntime as dirname,
  basenameRuntime as basename,
  extnameRuntime as extname,
  sepRuntime as sepRuntime,
  delimiterRuntime as delimiter,
  parseRuntime as parse,
  formatRuntime as format,
  posixRuntime as posix,
  win32Runtime as win32,
};
